Installazione di ONLYOFFICE Apps Developer con parametri aggiuntivi dello script
Introduzione
ONLYOFFICE Apps Developer è una versione a pagamento di un hub documentale dove puoi connettere utenti e documenti in un unico luogo per migliorare la collaborazione.
ONLYOFFICE Apps Developer viene fornito come script di installazione automatica per sistemi operativi Linux con Docker installato. Lo script configurerà i container Docker con tutti i componenti necessari per il corretto funzionamento di ONLYOFFICE Apps Developer ed è facile da eseguire, gestire e aggiornare.
Dopo aver scaricato lo script di installazione di ONLYOFFICE Apps Developer, potresti doverlo eseguire specificando alcuni parametri aggiuntivi, ad esempio, se desideri installare ciascun componente su una macchina separata.
Usa il seguente comando per visualizzare l'elenco di tutti i parametri disponibili dello script Docker:
bash apps-developer-install.sh docker -h
Usa il seguente comando per visualizzare l'elenco di tutti i parametri disponibili dello script DEB/RPM:
bash apps-developer-install.sh package -h
Di seguito puoi trovare una breve descrizione e alcuni esempi di utilizzo per questi parametri.
Quando esegui lo script con i parametri, ti verrà chiesto di selezionare il modo in cui desideri installare ONLYOFFICE Apps. Digita Y e premi Invio per installare ONLYOFFICE Apps utilizzando Docker. Digita N e premi Invio per installare ONLYOFFICE Apps dai pacchetti DEB/RPM.
Credenziali
| Parametro | Descrizione |
|---|---|
-reg, --registry | URL del registro Docker (es., https://myregistry.com:5000) |
-un, --username | login del registro Docker |
-p, --password | password del registro Docker |
Questi parametri vengono utilizzati nel caso in cui ti forniamo le credenziali per accedere a un repository di test, in modo che tu possa eseguire i container dalle immagini memorizzate in esso.
Esempio
bash apps-developer-install.sh -reg URL -un username -p password
Tipo di installazione
| Parametro | Descrizione | Valori | Predefinito |
|---|---|---|---|
-it, --installationtype | tipo di installazione | community|developer|enterprise | developer |
Questo parametro ti consente di installare la soluzione specificata: ONLYOFFICE Apps Community, ONLYOFFICE Apps Developer o ONLYOFFICE Apps Enterprise.
Esempio
bash apps-developer-install.sh -it community
Questo installerà la soluzione ONLYOFFICE Apps Community.
Verifica hardware
| Parametro | Descrizione | Valori | Predefinito |
|---|---|---|---|
-skiphc, --skiphardwarecheck | usa per saltare la verifica hardware | true|false | false |
Questo parametro ti consente di saltare la verifica se il sistema soddisfa i requisiti hardware minimi.
Esempio
bash apps-developer-install.sh -skiphc true
Questo salterà la verifica hardware.
Aggiornamento componenti
| Parametro | Descrizione | Valori | Predefinito |
|---|---|---|---|
-u, --update | usa per aggiornare i componenti esistenti | true|false | false |
Questo parametro ti consente di installare le versioni più recenti dei componenti necessari se i componenti corrispondenti installati sulla tua macchina sono obsoleti.
Esempio
bash apps-developer-install.sh -u true
Questo fermerà di conseguenza quei container che devono essere aggiornati, li rimuoverà e quindi eseguirà le versioni più recenti dei componenti corrispondenti di ONLYOFFICE Apps Developer. Se la versione corrente del componente coincide con quella più recente disponibile, tale container non sarà influenzato. Se hai saltato alcuni componenti durante l'installazione precedente, verranno anch'essi saltati. I dati di ONLYOFFICE Apps dovrebbero essere rilevati automaticamente.
Aggiorna solo Docs alla versione 7.2.1.34 e salta l'aggiornamento per tutti gli altri componenti:
bash apps-developer-install.sh -u true -docsi onlyoffice/documentserver-de -docsv 7.2.1.34 -idocs true -ia false -irbt false -irds false
Aggiorna solo ONLYOFFICE Apps alla versione 1.2.0 e salta l'aggiornamento per tutti gli altri componenti:
bash apps-developer-install.sh -u true -asv v1.2.0 -idocs false -irbt false -irds false
Installazione componenti
| Parametro | Descrizione | Valori | Predefinito |
|---|---|---|---|
-ia, --installapps | installa ONLYOFFICE Apps | true|false | true |
-idocs, --installdocs | installa ONLYOFFICE Docs | true|false | true |
-irbt, --installrabbitmq | installa RabbitMQ | true|false | true |
-irds, --installredis | installa Redis | true|false | true |
-imysql, --installmysql | installa MySQL | true|false | true |
Questi parametri ti consentono di specificare se hai bisogno di installare un determinato componente o meno. Possono essere utilizzati se desideri installare ciascun componente su una macchina separata.
- Usa il valore
trueper installare un componente. - Usa il valore
falseper saltare l'installazione di un componente.
Esempio
bash apps-developer-install.sh -idocs false
Questo installerà tutti i componenti di ONLYOFFICE Apps Developer senza ONLYOFFICE Docs.
bash apps-developer-install.sh -ia false -idocs true -imysql false -irbt false -irds false
Questo salterà l'installazione di ONLYOFFICE Apps, MySQL, RabbitMQ e Redis e installerà solo ONLYOFFICE Docs.
Versione componenti
| Parametro | Descrizione |
|---|---|
-asv, --appsversion | versione di ONLYOFFICE Apps |
-docsv, --docsversion | versione di ONLYOFFICE Docs |
Questi parametri possono essere utilizzati per installare una certa versione di ONLYOFFICE Apps o ONLYOFFICE Docs se per qualche motivo non si desidera installare l'ultima versione disponibile nel repository. Di default, un'immagine etichettata come latest viene utilizzata per eseguire il contenitore del componente.
Esempio
Apri il repository su Docker Hub nel tuo browser, seleziona ONLYOFFICE Docs e vai alla scheda Tags per visualizzare tutti i tag disponibili nel repository. Specifica la versione che desideri installare:
bash apps-developer-install.sh -docsv 7.2.1.34
Questo installerà ONLYOFFICE Apps con la versione 7.2.1.34 di ONLYOFFICE Docs.
Nome immagine ONLYOFFICE Docs
| Parametro | Descrizione |
|---|---|
-docsi, --docsimage | Nome immagine ONLYOFFICE Docs |
Questo parametro può essere utilizzato per specificare un nome dell'immagine ONLYOFFICE Docs da cui avviare un contenitore. L'immagine specificata deve essere memorizzata nel nostro repository pubblico ufficiale su Docker Hub.
Esempio
bash apps-developer-install.sh -docsi onlyoffice/documentserver-de
Questo eseguirà un contenitore dall'immagine ONLYOFFICE Docs specificata memorizzata nel repository.
Impostazioni per gli host
| Parametro | Descrizione |
|---|---|
-ash, --appshost | Host ONLYOFFICE Apps |
-esh, --elastichost | Host OpenSearch |
Questi parametri possono essere utilizzati per connettere i componenti se li installi su macchine separate.
Esempio
bash apps-developer-install.sh -esh 192.168.3.202
Questo installerà ONLYOFFICE Apps e lo connetterà con OpenSearch installato su una macchina diversa che ha l'indirizzo IP 192.168.3.202.
Impostazioni per core.machinekey
| Parametro | Descrizione |
|---|---|
-mk, --machinekey | Impostazioni per la chiave core.machinekey |
Questo parametro ti permette di specificare la tua chiave machinekey durante l'installazione di ONLYOFFICE Apps Developer.
Questo parametro viene scritto nel file di configurazione /app/onlyoffice/config/appsettings.json (il percorso è specificato all'interno del contenitore onlyoffice-studio).
Esempio
bash apps-developer-install.sh -mk yourmachinekey
Porta esterna ONLYOFFICE Apps
| Parametro | Descrizione | Predefinito |
|---|---|---|
-ep, --externalport | Porta esterna ONLYOFFICE Apps | 80 |
Questo parametro ti permette di cambiare la porta su cui ONLYOFFICE Apps verrà eseguito. Di default, viene utilizzata la porta 80.
Esempio
bash apps-developer-install.sh -ep 8080
Impostazioni per l'intestazione e il segreto JWT
| Parametro | Descrizione |
|---|---|
-jh, --jwtheader | Impostazioni per l'intestazione JWT |
-js, --jwtsecret | Impostazioni per la chiave segreta JWT |
Questi parametri ti permettono di specificare l'intestazione JWT e la tua chiave segreta JWT durante l'installazione di ONLYOFFICE Apps Developer. L'intestazione JWT definisce l'intestazione http che verrà utilizzata per inviare il JWT. La chiave segreta viene utilizzata per firmare il token web JSON e convalidare il token alla richiesta a ONLYOFFICE Docs.
Questi parametri vengono scritti nei seguenti file di configurazione (i percorsi sono specificati all'interno dei contenitori onlyoffice-studio e onlyoffice-document-server):
- Per ONLYOFFICE Apps -
/app/onlyoffice/config/appsettings.json - Per Document Server -
/etc/onlyoffice/documentserver/local.json
Esempio
bash apps-developer-install.sh -js yoursecret
Server MySQL
| Parametro | Descrizione | Predefinito |
|---|---|---|
-mysqlrp, --mysqlrootpassword | Password root del server MySQL | generato automaticamente |
-mysqlh, --mysqlhost | Host del server MySQL | localhost |
-mysqlport, --mysqlport | Numero di porta del server MySQL | 3306 |
Se non specifichi esplicitamente l'host e la porta, vengono utilizzati i valori predefiniti. La password root viene generata automaticamente se non la imposti.
Esempio
bash apps-developer-install.sh -mysqlrp new-secret-pw
Questo comando ti permette di impostare la tua password per l'account root di MySQL durante l'installazione di ONLYOFFICE Apps Developer.
Database ONLYOFFICE Apps
| Parametro | Descrizione | Predefinito |
|---|---|---|
-mysqld, --mysqldatabase | Nome del database ONLYOFFICE Apps | onlyoffice_apps |
-mysqlu, --mysqluser | Utente del database ONLYOFFICE Apps | - |
-mysqlp, --mysqlpassword | Password del database ONLYOFFICE Apps | generato automaticamente |
Questi parametri ti permettono di creare il database ONLYOFFICE Apps specificando un nome personalizzato per il database, oltre a un nome utente e una password per l'account con permessi di superutente sul database creato. Se non specifichi esplicitamente il nome del database, viene utilizzato il valore predefinito. Se non imposti una password, viene generata automaticamente.
Esempio
bash apps-developer-install.sh -mysqld appsdatabase -mysqlu username -mysqlp password
Server RabbitMQ
| Parametro | Descrizione | Predefinito |
|---|---|---|
--rabbitmqprotocol | Protocollo di connessione RabbitMQ | amqp |
--rabbitmqhost | Host del server RabbitMQ | localhost |
--rabbitmqport | Numero di porta del server RabbitMQ | 5672 |
--rabbitmqusername | Nome utente RabbitMQ | - |
--rabbitmqpassword | Password utente RabbitMQ | - |
--rabbitmqvirtualhost | Host virtuale RabbitMQ | / |
Usa questi parametri per connettere ONLYOFFICE Apps a un server RabbitMQ già in esecuzione su un'altra macchina. Salta l'installazione di RabbitMQ con il parametro -irbt false, quindi specifica i parametri di connessione del tuo server. Se non specifichi esplicitamente il protocollo, l'host, la porta o l'host virtuale, vengono utilizzati i valori predefiniti.
Esempio
bash apps-developer-install.sh -irbt false --rabbitmqhost mq.example.com --rabbitmqusername username --rabbitmqpassword password
Questo installerà ONLYOFFICE Apps senza RabbitMQ e lo connetterà al server RabbitMQ in esecuzione sull'host mq.example.com.
Server Redis
| Parametro | Descrizione | Predefinito |
|---|---|---|
--redishost | Host del server Redis | localhost |
--redisport | Numero di porta del server Redis | 6379 |
--redisusername | Nome utente Redis, se il server richiede l'autorizzazione | - |
--redispassword | Password utente Redis, se il server richiede l'autorizzazione | - |
Usa questi parametri per connettere ONLYOFFICE Apps a un server Redis già in esecuzione su un'altra macchina. Salta l'installazione di Redis con il parametro -irds false, quindi specifica i parametri di connessione del tuo server. Il nome utente e la password sono necessari solo se il tuo server Redis richiede l'autorizzazione.
Esempio
bash apps-developer-install.sh -irds false --redishost redis.example.com --redispassword password
Questo installerà ONLYOFFICE Apps senza Redis e lo connetterà al server Redis in esecuzione sull'host redis.example.com.
Server OpenSearch
| Parametro | Descrizione | Predefinito |
|---|---|---|
--elasticprotocol | Protocollo di connessione OpenSearch | http |
--elasticport | Numero di porta del server OpenSearch | 9200 |
Usa questi parametri insieme al parametro -esh, --elastichost descritto nella sezione «Impostazioni per gli host» sopra per connettere ONLYOFFICE Apps a un server OpenSearch in esecuzione su un'altra macchina. Se non specifichi esplicitamente il protocollo e la porta, vengono utilizzati i valori predefiniti.
Esempio
bash apps-developer-install.sh -esh search.example.com --elasticprotocol https --elasticport 9200
Questo connetterà ONLYOFFICE Apps al server OpenSearch in esecuzione sull'host search.example.com tramite HTTPS.
Passaggio a HTTPS
| Parametro | Descrizione |
|---|---|
-led, --letsencryptdomain | definisce il dominio per il certificato Let's Encrypt |
-lem, --letsencryptmail | definisce l'indirizzo email dell'amministratore del dominio per il certificato Let's Encrypt |
-cf, --certfile | percorso al file del certificato per il dominio |
-ckf, --certkeyfile | percorso al file della chiave privata per il certificato |
Questi parametri ti permettono di passare lo spazio di lavoro a HTTPS. Possono essere utilizzati solo per la versione Docker.
Esempio
bash apps-developer-install.sh docker --letsencryptmail user@example.com --letsencryptdomain yourdomain.com
Questo creerà e installerà automaticamente il certificato firmato dalla CA di letsencrypt.org sul tuo server e riavvierà il servizio NGINX affinché le modifiche abbiano effetto.
bash apps-developer-install.sh docker --certfile path --certkeyfile path
Questo applicherà il tuo certificato SSL.